@@ -220,8 +220,7 @@ class trainer:
                 scan_path = os.path.join("lang", f"{self._language}-verbs.txt")
                 verb_file = open(scan_path, encoding="utf-8") #Se abre el archivo que contiene todas las formas verbales de los verbos en español
             else:
-                from . import lang
-                verb_file = pkg_resources.open_text(lang, f"{self._language}-verbs.txt")
+                verb_file = pkg_resources.open_text(__package__, f"{self._language}-verbs.txt")
             va = verb_file.read().split()
         except FileNotFoundError:
             print("""The language input does not exist in our database, check if the input was
